--
-- PostgreSQL database dump
--

-- Dumped from database version 9.5.5
-- Dumped by pg_dump version 9.5.5

SET statement_timeout = 0;
SET lock_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = ON;
SET check_function_bodies = FALSE;
SET client_min_messages = WARNING;
SET row_security = OFF;

SET search_path = public, pg_catalog;

--
-- Name: calculate_score_for_softwares_statistics(); Type: FUNCTION; Schema: public; Owner: comptoir
--

CREATE FUNCTION calculate_score_for_softwares_statistics()
    RETURNS VOID
LANGUAGE plpgsql
AS $$DECLARE calculated_score REAL;

    DECLARE  stats_line       softwares_statistics%ROWTYPE;
    DECLARE  stats            softwares_statistics.software_id%TYPE;

    DECLARE  total_softwares  INTEGER;

BEGIN

    SELECT count(id)
    INTO total_softwares
    FROM softwares_statistics;

    FOR stats_line IN SELECT *
                      FROM softwares_statistics LOOP

        /* Get points */
        calculated_score :=
        (stats_line.last_commit_age +
         stats_line.project_age +
         stats_line.delta_commit_one_month +
         stats_line.delta_commit_one_year +
         stats_line.nb_contributors +
         stats_line.contributors_code_percent +
         stats_line.declared_users +
         stats_line.average_review_score +
         stats_line.screenshots) / 29 * 100;

        /* Update the statistics table */
        UPDATE softwares_statistics
        SET score = calculated_score
        WHERE software_id = stats_line.software_id;

    END LOOP;
END;
$$;


ALTER FUNCTION public.calculate_score_for_softwares_statistics()
OWNER TO comptoir;

--
-- Name: calculated_points_from_manivelle(); Type: FUNCTION; Schema: public; Owner: comptoir
--

CREATE FUNCTION calculated_points_from_manivelle()
    RETURNS VOID
LANGUAGE plpgsql
AS $$
DECLARE     point_reviews      INTEGER;
    DECLARE points_screenshots INTEGER;
    DECLARE point_users_of     INTEGER;

    DECLARE stats_line         softwares_statistics%ROWTYPE;
    DECLARE stats              softwares_statistics.software_id%TYPE;


BEGIN
    FOR stats_line IN SELECT *
                      FROM softwares_statistics LOOP

        /*RAISE NOTICE  'test %' ,stats_line.software_id;*/
        /* Get points */
        point_reviews := points_for_reviews(stats_line.software_id);
        points_screenshots := points_for_screenshots(stats_line.software_id);
        point_users_of := points_for_users_of(stats_line.software_id);

        /* Update the statistics table */
        UPDATE softwares_statistics
        SET average_review_score = point_reviews,
            screenshots          = points_screenshots,
            declared_users       = point_users_of
        WHERE software_id = stats_line.software_id;

    END LOOP;
END
$$;


ALTER FUNCTION public.calculated_points_from_manivelle()
OWNER TO comptoir;

--
-- Name: calculated_points_from_server(); Type: FUNCTION; Schema: public; Owner: comptoir
--

CREATE FUNCTION calculated_points_from_server()
    RETURNS VOID
LANGUAGE plpgsql
AS $$DECLARE total_softwares                  REAL;
    DECLARE  raw_line                         raw_metrics_softwares%ROWTYPE;
    DECLARE  avg_delta_commit_1m              REAL;
    DECLARE  avg_delta_commit_12m             REAL;
    DECLARE  avg_hight_commiter_percent       REAL;
    DECLARE  avg_number_of_contributors       REAL;
    DECLARE  final_avg_delta_commit_1m        REAL;
    DECLARE  final_avg_delta_commit_12m       REAL;
    DECLARE  final_avg_hight_commiter_percent REAL;
    DECLARE  final_avg_number_of_contributors REAL;

BEGIN
    SELECT COUNT(*)
    INTO total_softwares
    FROM (SELECT DISTINCT software_id
          FROM raw_metrics_softwares) AS count;

    avg_delta_commit_1m := 0;
    avg_delta_commit_12m := 0;
    avg_hight_commiter_percent := 0;
    avg_number_of_contributors := 0;

    FOR raw_line IN (WITH grouped_softwares AS (SELECT
                                                    *,
                                                    ROW_NUMBER()
                                                    OVER (PARTITION BY software_id
                                                        ORDER BY id DESC) AS rk
                                                FROM raw_metrics_softwares) SELECT g.*
                                                                            FROM grouped_softwares g
                                                                            WHERE g.rk = 1) LOOP

        /* Get sum */
        avg_delta_commit_1m := avg_delta_commit_1m + (raw_line.delta_commit_one_month);
        avg_delta_commit_12m := avg_delta_commit_12m + (raw_line.delta_commit_twelve_month);
        avg_hight_commiter_percent := avg_hight_commiter_percent + (raw_line.high_committer_percent);
        avg_number_of_contributors := avg_number_of_contributors + (raw_line.number_of_contributors);

    END LOOP;

    /* Get average */
    avg_delta_commit_1m         := avg_delta_commit_1m / total_softwares;
    avg_delta_commit_12m        := avg_delta_commit_12m / total_softwares;
    avg_hight_commiter_percent  := avg_hight_commiter_percent / total_softwares;
    avg_number_of_contributors  := avg_number_of_contributors / total_softwares;


    FOR raw_line IN (WITH grouped_softwares AS (SELECT
                                                    *,
                                                    ROW_NUMBER()
                                                    OVER (PARTITION BY software_id
                                                        ORDER BY id DESC) AS rk
                                                FROM raw_metrics_softwares) SELECT g.*
                                                                            FROM grouped_softwares g
                                                                            WHERE g.rk = 1) LOOP

        final_avg_delta_commit_1m := (raw_line.delta_commit_one_month - avg_delta_commit_1m) / avg_delta_commit_1m *
                                     100;
        final_avg_delta_commit_12m := (raw_line.delta_commit_twelve_month - avg_delta_commit_12m) / avg_delta_commit_12m
                                      * 100;
        final_avg_hight_commiter_percent := raw_line.high_committer_percent;
        /*(raw_line.high_committer_percent-avg_hight_commiter_percent)/avg_hight_commiter_percent*100;*/
        final_avg_number_of_contributors :=
        (raw_line.number_of_contributors - avg_number_of_contributors) / avg_number_of_contributors * 100;

        PERFORM score_age(raw_line.project_age, raw_line.last_commit_age, raw_line.software_id);
        PERFORM score_delta_commit_1m(final_avg_delta_commit_1m, raw_line.software_id);
        PERFORM score_delta_commit_12m(final_avg_delta_commit_12m, raw_line.software_id);
        PERFORM score_hight_commiter_percent(final_avg_hight_commiter_percent, raw_line.software_id);
        PERFORM score_number_of_contributors(final_avg_number_of_contributors, raw_line.software_id);


    END LOOP;

END;$$;


ALTER FUNCTION public.calculated_points_from_server()
OWNER TO comptoir;

--
-- Name: points_for_reviews(integer); Type: FUNCTION; Schema: public; Owner: comptoir
--

CREATE FUNCTION points_for_reviews(stats_id INTEGER)
    RETURNS REAL
LANGUAGE plpgsql
AS $$DECLARE total_reviews REAL;
    DECLARE  points        REAL;
BEGIN
    points :=0;
    SELECT avg(reviews.evaluation)
    INTO total_reviews
    FROM reviews
    WHERE reviews.software_id = stats_id;

    IF total_reviews > 2.5
    THEN points := 2;
    ELSIF total_reviews <= 2.5
        THEN points := 1;
    ELSIF total_reviews = 0
        THEN points := 0;
    END IF;
    RETURN points;
END;
$$;


ALTER FUNCTION public.points_for_reviews(stats_id INTEGER )
OWNER TO comptoir;

--
-- Name: points_for_screenshots(integer); Type: FUNCTION; Schema: public; Owner: comptoir
--

CREATE FUNCTION points_for_screenshots(stats_id INTEGER)
    RETURNS INTEGER
LANGUAGE plpgsql
AS $$

DECLARE     total_screenshots INTEGER;
    DECLARE points            INTEGER;

BEGIN
    SELECT count(screenshots.id)
    INTO total_screenshots
    FROM screenshots
    WHERE screenshots.software_id = stats_id;

    IF total_screenshots > 2
    THEN points := 2;
    ELSIF total_screenshots BETWEEN 0 AND 2
        THEN points = 1;
    ELSIF total_screenshots = 0
        THEN points := 0;
    END IF;
    RETURN points;
END;
$$;


ALTER FUNCTION public.points_for_screenshots(stats_id INTEGER )
OWNER TO comptoir;

--
-- Name: points_for_users_of(integer); Type: FUNCTION; Schema: public; Owner: comptoir
--

CREATE FUNCTION points_for_users_of(stats_id INTEGER)
    RETURNS INTEGER
LANGUAGE plpgsql
AS $$DECLARE total_users_of INTEGER;
    DECLARE  points         INTEGER;
BEGIN
    SELECT count(relationships_softwares_users.id)
    INTO total_users_of
    FROM relationships_softwares_users
    WHERE relationships_softwares_users.software_id = stats_id;

    IF total_users_of > 5
    THEN points := 2;
    ELSIF total_users_of BETWEEN 0 AND 5
        THEN points = 1;
    ELSIF total_users_of = 0
        THEN points := 0;
    END IF;
    RETURN points;
END;
$$;


ALTER FUNCTION public.points_for_users_of(stats_id INTEGER )
OWNER TO comptoir;

--
-- Name: raw_metrics_from_manivelle(); Type: FUNCTION; Schema: public; Owner: comptoir
--

CREATE FUNCTION raw_metrics_from_manivelle()
    RETURNS VOID
LANGUAGE plpgsql
AS $$DECLARE avg_reviews       DECIMAL;
    DECLARE  total_screenshots INTEGER;
    DECLARE  total_users_of    INTEGER;

    DECLARE  stats_line        raw_metrics_softwares%ROWTYPE;
    DECLARE  id_software       raw_metrics_softwares.software_id%TYPE;


BEGIN
    FOR stats_line IN SELECT *
                      FROM raw_metrics_softwares LOOP

        /*RAISE NOTICE  'test %' ,stats_line.software_id;*/
        /* Get points */
        SELECT avg(reviews.evaluation)
        INTO avg_reviews
        FROM reviews
        WHERE reviews.software_id = stats_line.software_id;

        SELECT count(screenshots.id)
        INTO total_screenshots
        FROM screenshots
        WHERE screenshots.software_id = stats_line.software_id;

        SELECT count(relationships_softwares_users.id)
        INTO total_users_of
        FROM relationships_softwares_users
        WHERE relationships_softwares_users.software_id = stats_line.software_id;

        /* Update the statistics table */
        UPDATE raw_metrics_softwares
        SET average_review_score = avg_reviews,
            screenshots          = total_screenshots,
            declared_users       = total_users_of
        WHERE software_id = stats_line.software_id;

    END LOOP;
END

$$;


ALTER FUNCTION public.raw_metrics_from_manivelle()
OWNER TO comptoir;

--
-- Name: score_age(integer, integer, integer); Type: FUNCTION; Schema: public; Owner: comptoir
--

CREATE FUNCTION score_age(p_project_age INTEGER, p_commit_age INTEGER, p_id INTEGER)
    RETURNS VOID
LANGUAGE plpgsql
AS $$

DECLARE     d_score_project INTEGER;
    DECLARE d_score_commit  INTEGER;

BEGIN

    IF p_project_age > 365 * 5
    THEN d_score_project := 2;
    ELSIF p_project_age > 365 * 3
        THEN d_score_project := 1;
    ELSE d_score_project :=0;
    END IF;

    IF p_commit_age > 365 * 3
    THEN d_score_commit := 0;
    ELSIF p_commit_age > 365 * 2
        THEN d_score_commit := 1;
    ELSIF p_commit_age > 90
        THEN d_score_commit := 2;
    ELSIF p_commit_age > 30
        THEN d_score_commit := 3;
    ELSE d_score_commit :=4;
    END IF;

    IF EXISTS(SELECT id
              FROM softwares_statistics
              WHERE software_id = p_id)
    THEN UPDATE softwares_statistics
    SET project_age = d_score_project, last_commit_age = d_score_commit
    WHERE software_id = p_id;
    ELSE INSERT INTO softwares_statistics (software_id, project_age, last_commit_age)
    VALUES (p_id, d_score_project, d_score_commit);
    END IF;

END;$$;


ALTER FUNCTION public.score_age(p_project_age INTEGER, p_commit_age INTEGER, p_id INTEGER )
OWNER TO comptoir;

--
-- Name: FUNCTION score_age(p_project_age integer, p_commit_age integer, p_id integer); Type: COMMENT; Schema: public; Owner: comptoir
--

COMMENT ON FUNCTION score_age(p_project_age INTEGER, p_commit_age INTEGER, p_id INTEGER) IS 'updates the scores based on age

NOTE: this needs to be the first function called to avoid updating a row that does not exist!';

--
-- Name: score_delta_commit_12m(real, integer); Type: FUNCTION; Schema: public; Owner: comptoir
--

CREATE FUNCTION score_delta_commit_12m(p_pourcentage_delta_12m REAL, p_id INTEGER)
    RETURNS VOID
LANGUAGE plpgsql
AS $$

DECLARE     d_score        INTEGER;
    DECLARE d_score_commit INTEGER;

BEGIN

    IF p_pourcentage_delta_12m > 50
    THEN d_score := 4;
    ELSIF p_pourcentage_delta_12m > 25
        THEN d_score := 3;
    ELSIF p_pourcentage_delta_12m > -25
        THEN d_score := 1;
    ELSE d_score :=0;
    END IF;

    UPDATE softwares_statistics
    SET delta_commit_one_year = d_score
    WHERE software_id = p_id;

END;$$;


ALTER FUNCTION public.score_delta_commit_12m(p_pourcentage_delta_12m REAL, p_id INTEGER )
OWNER TO comptoir;

--
-- Name: score_delta_commit_1m(real, integer); Type: FUNCTION; Schema: public; Owner: comptoir
--

CREATE FUNCTION score_delta_commit_1m(p_pourcentage_delta_1m REAL, p_id INTEGER)
    RETURNS VOID
LANGUAGE plpgsql
AS $$

DECLARE d_score INTEGER;

BEGIN

    IF p_pourcentage_delta_1m > 50
    THEN d_score := 4;
    ELSIF p_pourcentage_delta_1m > 25
        THEN d_score := 3;
    ELSIF p_pourcentage_delta_1m > -25
        THEN d_score := 1;
    ELSE d_score :=0;
    END IF;

    UPDATE softwares_statistics
    SET delta_commit_one_month = d_score
    WHERE software_id = p_id;

END;$$;


ALTER FUNCTION public.score_delta_commit_1m(p_pourcentage_delta_1m REAL, p_id INTEGER )
OWNER TO comptoir;

--
-- Name: score_hight_commiter_percent(real, integer); Type: FUNCTION; Schema: public; Owner: comptoir
--

CREATE FUNCTION score_hight_commiter_percent(p_pourcentage_high REAL, p_id INTEGER)
    RETURNS VOID
LANGUAGE plpgsql
AS $$

DECLARE d_score INTEGER;

BEGIN

    IF p_pourcentage_high > 90
    THEN d_score := 0;
    ELSIF p_pourcentage_high > 50
        THEN d_score := 2;
    ELSIF p_pourcentage_high > 10
        THEN d_score := 3;
    ELSE d_score :=4;
    END IF;

    UPDATE softwares_statistics
    SET contributors_code_percent = d_score
    WHERE software_id = p_id;

END;$$;


ALTER FUNCTION public.score_hight_commiter_percent(p_pourcentage_high REAL, p_id INTEGER )
OWNER TO comptoir;

--
-- Name: score_number_of_contributors(real, integer); Type: FUNCTION; Schema: public; Owner: comptoir
--

CREATE FUNCTION score_number_of_contributors(pourcentage_nb_contributors REAL, p_id INTEGER)
    RETURNS VOID
LANGUAGE plpgsql
AS $$

DECLARE d_score INTEGER;

BEGIN

    IF pourcentage_nb_contributors > 50
    THEN d_score := 4;
    ELSIF pourcentage_nb_contributors > 25
        THEN d_score := 3;
    ELSIF pourcentage_nb_contributors > 0
        THEN d_score := 1;
    ELSE d_score :=0;
    END IF;

    UPDATE softwares_statistics
    SET nb_contributors = d_score
    WHERE software_id = p_id;

END;
$$;


ALTER FUNCTION public.score_number_of_contributors(pourcentage_nb_contributors REAL, p_id INTEGER )
OWNER TO comptoir;

SET default_tablespace = '';

SET default_with_oids = FALSE;

--
-- Name: licence_types; Type: TABLE; Schema: public; Owner: comptoir
--

CREATE TABLE licence_types (
    id       BIGINT NOT NULL,
    name     TEXT,
    created  TIMESTAMP WITH TIME ZONE,
    modified TIMESTAMP WITH TIME ZONE,
    cd       TEXT
);


ALTER TABLE licence_types
    OWNER TO comptoir;

--
-- Name: licence_types_id_seq; Type: SEQUENCE; Schema: public; Owner: comptoir
--

CREATE SEQUENCE licence_types_id_seq
START WITH 1
INCREMENT BY 1
NO MINVALUE
NO MAXVALUE
CACHE 1;


ALTER TABLE licence_types_id_seq
    OWNER TO comptoir;

--
-- Name: licence_types_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: comptoir
--

ALTER SEQUENCE licence_types_id_seq OWNED BY licence_types.id;

--
-- Name: licenses; Type: TABLE; Schema: public; Owner: comptoir
--

CREATE TABLE licenses (
    id              BIGINT NOT NULL,
    name            TEXT   NOT NULL,
    license_type_id BIGINT NOT NULL,
    created         TIMESTAMP WITH TIME ZONE,
    modified        TIMESTAMP WITH TIME ZONE
);


ALTER TABLE licenses
    OWNER TO comptoir;

--
-- Name: licenses_id_seq; Type: SEQUENCE; Schema: public; Owner: comptoir
--

CREATE SEQUENCE licenses_id_seq
START WITH 1
INCREMENT BY 1
NO MINVALUE
NO MAXVALUE
CACHE 1;


ALTER TABLE licenses_id_seq
    OWNER TO comptoir;

--
-- Name: licenses_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: comptoir
--

ALTER SEQUENCE licenses_id_seq OWNED BY licenses.id;

--
-- Name: panels; Type: TABLE; Schema: public; Owner: comptoir
--

CREATE TABLE panels (
    id         UUID NOT NULL,
    request_id UUID NOT NULL,
    panel      CHARACTER VARYING,
    title      CHARACTER VARYING,
    element    CHARACTER VARYING,
    summary    CHARACTER VARYING,
    content    BYTEA
);


ALTER TABLE panels
    OWNER TO comptoir;

--
-- Name: phinxlog; Type: TABLE; Schema: public; Owner: comptoir
--

CREATE TABLE phinxlog (
    version    BIGINT                      NOT NULL,
    start_time TIMESTAMP WITHOUT TIME ZONE NOT NULL,
    end_time       TIMESTAMP WITHOUT TIME ZONE NOT NULL,
    migration_name CHARACTER VARYING(100)
);


ALTER TABLE phinxlog
    OWNER TO comptoir;

--
-- Name: raw_metrics_softwares; Type: TABLE; Schema: public; Owner: comptoir
--

CREATE TABLE raw_metrics_softwares (
    id                           INTEGER NOT NULL,
    software_id                  INTEGER,
    name                         CHARACTER VARYING(255),
    created                      TIMESTAMP WITHOUT TIME ZONE,
    modified                     TIMESTAMP WITHOUT TIME ZONE,
    last_commit_age              INTEGER NOT NULL,
    high_committer_percent       REAL    NOT NULL,
    number_of_contributors       INTEGER NOT NULL,
    declared_users               INTEGER,
    average_review_score         NUMERIC,
    screenshots                  INTEGER,
    code_gouv_label              INTEGER,
    metrics_date                 TIMESTAMP WITHOUT TIME ZONE,
    project_age                  INTEGER,
    delta_commit_one_month       INTEGER,
    delta_commit_twelve_month    INTEGER,
    commit_activity_one_month    REAL,
    commit_activity_twelve_month REAL
);


ALTER TABLE raw_metrics_softwares
    OWNER TO comptoir;

--
-- Name: raw_metrics_softwares_id_seq; Type: SEQUENCE; Schema: public; Owner: comptoir
--

CREATE SEQUENCE raw_metrics_softwares_id_seq
START WITH 1
INCREMENT BY 1
NO MINVALUE
NO MAXVALUE
CACHE 1;


ALTER TABLE raw_metrics_softwares_id_seq
    OWNER TO comptoir;

--
-- Name: raw_metrics_softwares_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: comptoir
--

ALTER SEQUENCE raw_metrics_softwares_id_seq OWNED BY raw_metrics_softwares.id;

--
-- Name: relationship_types; Type: TABLE; Schema: public; Owner: comptoir
--

CREATE TABLE relationship_types (
    id       BIGINT NOT NULL,
    name     TEXT,
    created  TIMESTAMP WITH TIME ZONE,
    modified TIMESTAMP WITH TIME ZONE,
    cd       TEXT
);


ALTER TABLE relationship_types
    OWNER TO comptoir;

--
-- Name: relationship_types_id_seq; Type: SEQUENCE; Schema: public; Owner: comptoir
--

CREATE SEQUENCE relationship_types_id_seq
START WITH 1
INCREMENT BY 1
NO MINVALUE
NO MAXVALUE
CACHE 1;


ALTER TABLE relationship_types_id_seq
    OWNER TO comptoir;

--
-- Name: relationship_types_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: comptoir
--

ALTER SEQUENCE relationship_types_id_seq OWNED BY relationship_types.id;

--
-- Name: relationships; Type: TABLE; Schema: public; Owner: comptoir
--

CREATE TABLE relationships (
    id                   BIGINT NOT NULL,
    name                 TEXT   NOT NULL,
    created              TIMESTAMP WITH TIME ZONE,
    modified             TIMESTAMP WITH TIME ZONE,
    cd                   TEXT,
    relationship_type_id BIGINT
);


ALTER TABLE relationships
    OWNER TO comptoir;

--
-- Name: relationships_id_seq; Type: SEQUENCE; Schema: public; Owner: comptoir
--

CREATE SEQUENCE relationships_id_seq
START WITH 1
INCREMENT BY 1
NO MINVALUE
NO MAXVALUE
CACHE 1;


ALTER TABLE relationships_id_seq
    OWNER TO comptoir;

--
-- Name: relationships_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: comptoir
--

ALTER SEQUENCE relationships_id_seq OWNED BY relationships.id;

--
-- Name: relationships_softwares; Type: TABLE; Schema: public; Owner: comptoir
--

CREATE TABLE relationships_softwares (
    id              BIGINT NOT NULL,
    software_id     BIGINT NOT NULL,
    relationship_id BIGINT NOT NULL,
    recipient_id    BIGINT NOT NULL,
    created         TIMESTAMP WITH TIME ZONE,
    modified        TIMESTAMP WITH TIME ZONE
);


ALTER TABLE relationships_softwares
    OWNER TO comptoir;

--
-- Name: relationships_softwares_id_seq; Type: SEQUENCE; Schema: public; Owner: comptoir
--

CREATE SEQUENCE relationships_softwares_id_seq
START WITH 1
INCREMENT BY 1
NO MINVALUE
NO MAXVALUE
CACHE 1;


ALTER TABLE relationships_softwares_id_seq
    OWNER TO comptoir;

--
-- Name: relationships_softwares_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: comptoir
--

ALTER SEQUENCE relationships_softwares_id_seq OWNED BY relationships_softwares.id;

--
-- Name: relationships_softwares_users; Type: TABLE; Schema: public; Owner: comptoir
--

CREATE TABLE relationships_softwares_users (
    id              BIGINT NOT NULL,
    software_id     BIGINT NOT NULL,
    user_id         BIGINT NOT NULL,
    relationship_id BIGINT NOT NULL,
    created         TIMESTAMP WITH TIME ZONE,
    modified        TIMESTAMP WITH TIME ZONE
);


ALTER TABLE relationships_softwares_users
    OWNER TO comptoir;

--
-- Name: relationships_softwares_users_id_seq; Type: SEQUENCE; Schema: public; Owner: comptoir
--

CREATE SEQUENCE relationships_softwares_users_id_seq
START WITH 1
INCREMENT BY 1
NO MINVALUE
NO MAXVALUE
CACHE 1;


ALTER TABLE relationships_softwares_users_id_seq
    OWNER TO comptoir;

--
-- Name: relationships_softwares_users_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: comptoir
--

ALTER SEQUENCE relationships_softwares_users_id_seq OWNED BY relationships_softwares_users.id;

--
-- Name: relationships_users; Type: TABLE; Schema: public; Owner: comptoir
--

CREATE TABLE relationships_users (
    id              BIGINT                   NOT NULL,
    user_id         BIGINT                   NOT NULL,
    recipient_id    BIGINT                   NOT NULL,
    relationship_id BIGINT                   NOT NULL,
    created         TIMESTAMP WITH TIME ZONE NOT NULL,
    modified        TIMESTAMP WITH TIME ZONE
);


ALTER TABLE relationships_users
    OWNER TO comptoir;

--
-- Name: relationships_users_id_seq; Type: SEQUENCE; Schema: public; Owner: comptoir
--

CREATE SEQUENCE relationships_users_id_seq
START WITH 1
INCREMENT BY 1
NO MINVALUE
NO MAXVALUE
CACHE 1;


ALTER TABLE relationships_users_id_seq
    OWNER TO comptoir;

--
-- Name: relationships_users_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: comptoir
--

ALTER SEQUENCE relationships_users_id_seq OWNED BY relationships_users.id;

--
-- Name: requests; Type: TABLE; Schema: public; Owner: comptoir
--

CREATE TABLE requests (
    id           UUID                        NOT NULL,
    url          CHARACTER VARYING           NOT NULL,
    content_type CHARACTER VARYING,
    status_code  INTEGER,
    method       CHARACTER VARYING,
    requested_at TIMESTAMP WITHOUT TIME ZONE NOT NULL
);


ALTER TABLE requests
    OWNER TO comptoir;

--
-- Name: reviews; Type: TABLE; Schema: public; Owner: comptoir
--

CREATE TABLE reviews (
    id          BIGINT                   NOT NULL,
    comment     TEXT                     NOT NULL,
    title       TEXT                     NOT NULL,
    created     TIMESTAMP WITH TIME ZONE NOT NULL,
    user_id     BIGINT,
    software_id BIGINT,
    evaluation  BIGINT,
    modified    TIMESTAMP WITH TIME ZONE
);


ALTER TABLE reviews
    OWNER TO comptoir;

--
-- Name: reviews_id_seq; Type: SEQUENCE; Schema: public; Owner: comptoir
--

CREATE SEQUENCE reviews_id_seq
START WITH 1
INCREMENT BY 1
NO MINVALUE
NO MAXVALUE
CACHE 1;


ALTER TABLE reviews_id_seq
    OWNER TO comptoir;

--
-- Name: reviews_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: comptoir
--

ALTER SEQUENCE reviews_id_seq OWNED BY reviews.id;

--
-- Name: screenshots; Type: TABLE; Schema: public; Owner: comptoir
--

CREATE TABLE screenshots (
    id            BIGINT NOT NULL,
    software_id   BIGINT,
    url_directory TEXT,
    created       TIMESTAMP WITH TIME ZONE,
    modified      TIMESTAMP WITH TIME ZONE,
    name          TEXT,
    photo         TEXT
);


ALTER TABLE screenshots
    OWNER TO comptoir;

--
-- Name: screenshots_id_seq; Type: SEQUENCE; Schema: public; Owner: comptoir
--

CREATE SEQUENCE screenshots_id_seq
START WITH 1
INCREMENT BY 1
NO MINVALUE
NO MAXVALUE
CACHE 1;


ALTER TABLE screenshots_id_seq
    OWNER TO comptoir;

--
-- Name: screenshots_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: comptoir
--

ALTER SEQUENCE screenshots_id_seq OWNED BY screenshots.id;

--
-- Name: softwares; Type: TABLE; Schema: public; Owner: comptoir
--

CREATE TABLE softwares (
    id             BIGINT NOT NULL,
    softwarename   TEXT,
    url_repository TEXT   NOT NULL,
    description    TEXT,
    licence_id     BIGINT,
    created        TIMESTAMP WITH TIME ZONE,
    modified       TIMESTAMP WITH TIME ZONE,
    logo_directory TEXT,
    photo          TEXT,
    url_website    CHARACTER VARYING(255)
);


ALTER TABLE softwares
    OWNER TO comptoir;

--
-- Name: softwares_id_seq; Type: SEQUENCE; Schema: public; Owner: comptoir
--

CREATE SEQUENCE softwares_id_seq
START WITH 1
INCREMENT BY 1
NO MINVALUE
NO MAXVALUE
CACHE 1;


ALTER TABLE softwares_id_seq
    OWNER TO comptoir;

--
-- Name: softwares_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: comptoir
--

ALTER SEQUENCE softwares_id_seq OWNED BY softwares.id;

--
-- Name: softwares_statistics; Type: TABLE; Schema: public; Owner: comptoir
--

CREATE TABLE softwares_statistics (
    id                        INTEGER NOT NULL,
    software_id               INTEGER,
    last_commit_age           INTEGER,
    project_age               INTEGER,
    delta_commit_one_month    INTEGER,
    delta_commit_twelve_month INTEGER,
    number_of_contributors    INTEGER,
    high_committer_percent    NUMERIC,
    declared_users            INTEGER,
    average_review_score      NUMERIC,
    screenshots               INTEGER,
    code_gouv_label           INTEGER,
    score                     NUMERIC
);


ALTER TABLE softwares_statistics
    OWNER TO comptoir;

--
-- Name: statistics_averages; Type: TABLE; Schema: public; Owner: comptoir
--

CREATE TABLE statistics_averages (
    id                        INTEGER                     NOT NULL,
    delta_commit_one_month    REAL                        NOT NULL,
    delta_commit_twelve_month REAL                        NOT NULL,
    number_of_contributors    REAL                        NOT NULL,
    created                   TIMESTAMP WITHOUT TIME ZONE NOT NULL,
    modified                  TIMESTAMP WITHOUT TIME ZONE NOT NULL
);


ALTER TABLE statistics_averages
    OWNER TO comptoir;

--
-- Name: statistics_averages_id_seq; Type: SEQUENCE; Schema: public; Owner: comptoir
--

CREATE SEQUENCE statistics_averages_id_seq
START WITH 1
INCREMENT BY 1
NO MINVALUE
NO MAXVALUE
CACHE 1;


ALTER TABLE statistics_averages_id_seq
    OWNER TO comptoir;

--
-- Name: statistics_averages_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: comptoir
--

ALTER SEQUENCE statistics_averages_id_seq OWNED BY statistics_averages.id;

--
-- Name: statistics_id_seq; Type: SEQUENCE; Schema: public; Owner: comptoir
--

CREATE SEQUENCE statistics_id_seq
START WITH 1
INCREMENT BY 1
NO MINVALUE
NO MAXVALUE
CACHE 1;


ALTER TABLE statistics_id_seq
    OWNER TO comptoir;

--
-- Name: statistics_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: comptoir
--

ALTER SEQUENCE statistics_id_seq OWNED BY softwares_statistics.id;

--
-- Name: user_types; Type: TABLE; Schema: public; Owner: comptoir
--

CREATE TABLE user_types (
    id       BIGINT NOT NULL,
    name     TEXT,
    created  TIMESTAMP WITH TIME ZONE,
    modified TIMESTAMP WITH TIME ZONE,
    cd       TEXT
);


ALTER TABLE user_types
    OWNER TO comptoir;

--
-- Name: user_types_id_seq; Type: SEQUENCE; Schema: public; Owner: comptoir
--

CREATE SEQUENCE user_types_id_seq
START WITH 1
INCREMENT BY 1
NO MINVALUE
NO MAXVALUE
CACHE 1;


ALTER TABLE user_types_id_seq
    OWNER TO comptoir;

--
-- Name: user_types_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: comptoir
--

ALTER SEQUENCE user_types_id_seq OWNED BY user_types.id;

--
-- Name: users; Type: TABLE; Schema: public; Owner: comptoir
--

CREATE TABLE users (
    id             BIGINT                   NOT NULL,
    username       TEXT,
    created        TIMESTAMP WITH TIME ZONE NOT NULL,
    logo_directory TEXT,
    url            TEXT,
    user_type_id   BIGINT                   NOT NULL,
    description    TEXT,
    modified       TIMESTAMP WITH TIME ZONE NOT NULL,
    role           TEXT                     NOT NULL,
    password       TEXT                     NOT NULL,
    email          TEXT,
    photo          TEXT,
    active         BOOLEAN DEFAULT FALSE,
    digest_hash    TEXT,
    token          UUID
);


ALTER TABLE users
    OWNER TO comptoir;

--
-- Name: users_id_seq; Type: SEQUENCE; Schema: public; Owner: comptoir
--

CREATE SEQUENCE users_id_seq
START WITH 1
INCREMENT BY 1
NO MINVALUE
NO MAXVALUE
CACHE 1;


ALTER TABLE users_id_seq
    OWNER TO comptoir;

--
-- Name: users_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: comptoir
--

ALTER SEQUENCE users_id_seq OWNED BY users.id;

--
-- Name: id; Type: DEFAULT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY licence_types
    ALTER COLUMN id SET DEFAULT nextval('licence_types_id_seq' :: REGCLASS);

--
-- Name: id; Type: DEFAULT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY licenses
    ALTER COLUMN id SET DEFAULT nextval('licenses_id_seq' :: REGCLASS);

--
-- Name: id; Type: DEFAULT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY raw_metrics_softwares
    ALTER COLUMN id SET DEFAULT nextval('raw_metrics_softwares_id_seq' :: REGCLASS);

--
-- Name: id; Type: DEFAULT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY relationship_types
    ALTER COLUMN id SET DEFAULT nextval('relationship_types_id_seq' :: REGCLASS);

--
-- Name: id; Type: DEFAULT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY relationships
    ALTER COLUMN id SET DEFAULT nextval('relationships_id_seq' :: REGCLASS);

--
-- Name: id; Type: DEFAULT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY relationships_softwares
    ALTER COLUMN id SET DEFAULT nextval('relationships_softwares_id_seq' :: REGCLASS);

--
-- Name: id; Type: DEFAULT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY relationships_softwares_users
    ALTER COLUMN id SET DEFAULT nextval('relationships_softwares_users_id_seq' :: REGCLASS);

--
-- Name: id; Type: DEFAULT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY relationships_users
    ALTER COLUMN id SET DEFAULT nextval('relationships_users_id_seq' :: REGCLASS);

--
-- Name: id; Type: DEFAULT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY reviews
    ALTER COLUMN id SET DEFAULT nextval('reviews_id_seq' :: REGCLASS);

--
-- Name: id; Type: DEFAULT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY screenshots
    ALTER COLUMN id SET DEFAULT nextval('screenshots_id_seq' :: REGCLASS);

--
-- Name: id; Type: DEFAULT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY softwares
    ALTER COLUMN id SET DEFAULT nextval('softwares_id_seq' :: REGCLASS);

--
-- Name: id; Type: DEFAULT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY softwares_statistics
    ALTER COLUMN id SET DEFAULT nextval('statistics_id_seq' :: REGCLASS);

--
-- Name: id; Type: DEFAULT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY statistics_averages
    ALTER COLUMN id SET DEFAULT nextval('statistics_averages_id_seq' :: REGCLASS);

--
-- Name: id; Type: DEFAULT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY user_types
    ALTER COLUMN id SET DEFAULT nextval('user_types_id_seq' :: REGCLASS);

--
-- Name: id; Type: DEFAULT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY users
    ALTER COLUMN id SET DEFAULT nextval('users_id_seq' :: REGCLASS);

--
-- Name: idx_26468_primary; Type: CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY licence_types
    ADD CONSTRAINT idx_26468_primary PRIMARY KEY (id);

--
-- Name: idx_26477_primary; Type: CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY licenses
    ADD CONSTRAINT idx_26477_primary PRIMARY KEY (id);

--
-- Name: idx_26486_primary; Type: CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY relationships
    ADD CONSTRAINT idx_26486_primary PRIMARY KEY (id);

--
-- Name: idx_26495_primary; Type: CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY relationships_softwares
    ADD CONSTRAINT idx_26495_primary PRIMARY KEY (id);

--
-- Name: idx_26501_primary; Type: CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY relationships_softwares_users
    ADD CONSTRAINT idx_26501_primary PRIMARY KEY (id);

--
-- Name: idx_26507_primary; Type: CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY relationships_users
    ADD CONSTRAINT idx_26507_primary PRIMARY KEY (id);

--
-- Name: idx_26513_primary; Type: CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY relationship_types
    ADD CONSTRAINT idx_26513_primary PRIMARY KEY (id);

--
-- Name: idx_26522_primary; Type: CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY reviews
    ADD CONSTRAINT idx_26522_primary PRIMARY KEY (id);

--
-- Name: idx_26531_primary; Type: CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY screenshots
    ADD CONSTRAINT idx_26531_primary PRIMARY KEY (id);

--
-- Name: idx_26540_primary; Type: CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY softwares
    ADD CONSTRAINT idx_26540_primary PRIMARY KEY (id);

--
-- Name: idx_26549_primary; Type: CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY users
    ADD CONSTRAINT idx_26549_primary PRIMARY KEY (id);

--
-- Name: idx_26558_primary; Type: CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY user_types
    ADD CONSTRAINT idx_26558_primary PRIMARY KEY (id);

--
-- Name: panels_pkey; Type: CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY panels
    ADD CONSTRAINT panels_pkey PRIMARY KEY (id);

--
-- Name: phinxlog_pkey; Type: CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY phinxlog
    ADD CONSTRAINT phinxlog_pkey PRIMARY KEY (version);

--
-- Name: raw_metrics_softwares_pkey; Type: CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY raw_metrics_softwares
    ADD CONSTRAINT raw_metrics_softwares_pkey PRIMARY KEY (id);

--
-- Name: requests_pkey; Type: CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY requests
    ADD CONSTRAINT requests_pkey PRIMARY KEY (id);

--
-- Name: statistics_averages_pkey; Type: CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY statistics_averages
    ADD CONSTRAINT statistics_averages_pkey PRIMARY KEY (id);

--
-- Name: statistics_pkey; Type: CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY softwares_statistics
    ADD CONSTRAINT statistics_pkey PRIMARY KEY (id);

--
-- Name: unique_panel; Type: CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY panels
    ADD CONSTRAINT unique_panel UNIQUE (request_id, panel);

--
-- Name: idx_26477_fk_license_licence_type_idx; Type: INDEX; Schema: public; Owner: comptoir
--

CREATE INDEX idx_26477_fk_license_licence_type_idx
    ON licenses USING BTREE (license_type_id);

--
-- Name: idx_26486_fk_relationships_relationship_types_idx; Type: INDEX; Schema: public; Owner: comptoir
--

CREATE INDEX idx_26486_fk_relationships_relationship_types_idx
    ON relationships USING BTREE (relationship_type_id);

--
-- Name: idx_26495_fk_software_relationship_relation_type_idx; Type: INDEX; Schema: public; Owner: comptoir
--

CREATE INDEX idx_26495_fk_software_relationship_relation_type_idx
    ON relationships_softwares USING BTREE (relationship_id);

--
-- Name: idx_26495_fk_software_relationship_software_from; Type: INDEX; Schema: public; Owner: comptoir
--

CREATE INDEX idx_26495_fk_software_relationship_software_from
    ON relationships_softwares USING BTREE (software_id);

--
-- Name: idx_26495_fk_software_relationship_to_idx; Type: INDEX; Schema: public; Owner: comptoir
--

CREATE INDEX idx_26495_fk_software_relationship_to_idx
    ON relationships_softwares USING BTREE (recipient_id);

--
-- Name: idx_26501_fk_entity_software_relationship_entity_idx; Type: INDEX; Schema: public; Owner: comptoir
--

CREATE INDEX idx_26501_fk_entity_software_relationship_entity_idx
    ON relationships_softwares_users USING BTREE (user_id);

--
-- Name: idx_26501_fk_entity_software_relationship_relationship_type_idx; Type: INDEX; Schema: public; Owner: comptoir
--

CREATE INDEX idx_26501_fk_entity_software_relationship_relationship_type_idx
    ON relationships_softwares_users USING BTREE (relationship_id);

--
-- Name: idx_26501_fk_user_software_relationship_software; Type: INDEX; Schema: public; Owner: comptoir
--

CREATE INDEX idx_26501_fk_user_software_relationship_software
    ON relationships_softwares_users USING BTREE (software_id);

--
-- Name: idx_26507_fk_entities_relationships_entities_idx; Type: INDEX; Schema: public; Owner: comptoir
--

CREATE INDEX idx_26507_fk_entities_relationships_entities_idx
    ON relationships_users USING BTREE (user_id);

--
-- Name: idx_26507_fk_entities_relationships_relationtion_types_idx; Type: INDEX; Schema: public; Owner: comptoir
--

CREATE INDEX idx_26507_fk_entities_relationships_relationtion_types_idx
    ON relationships_users USING BTREE (relationship_id);

--
-- Name: idx_26507_fk_entities_relationships_users_recipient_idx; Type: INDEX; Schema: public; Owner: comptoir
--

CREATE INDEX idx_26507_fk_entities_relationships_users_recipient_idx
    ON relationships_users USING BTREE (recipient_id);

--
-- Name: idx_26513_cd_unique; Type: INDEX; Schema: public; Owner: comptoir
--

CREATE UNIQUE INDEX idx_26513_cd_unique
    ON relationship_types USING BTREE (cd);

--
-- Name: idx_26513_name_unique; Type: INDEX; Schema: public; Owner: comptoir
--

CREATE UNIQUE INDEX idx_26513_name_unique
    ON relationship_types USING BTREE (name);

--
-- Name: idx_26522_fk_review_software_idx; Type: INDEX; Schema: public; Owner: comptoir
--

CREATE INDEX idx_26522_fk_review_software_idx
    ON reviews USING BTREE (software_id);

--
-- Name: idx_26522_fk_review_user_idx; Type: INDEX; Schema: public; Owner: comptoir
--

CREATE INDEX idx_26522_fk_review_user_idx
    ON reviews USING BTREE (user_id);

--
-- Name: idx_26531_fk_screens_software_idx; Type: INDEX; Schema: public; Owner: comptoir
--

CREATE INDEX idx_26531_fk_screens_software_idx
    ON screenshots USING BTREE (software_id);

--
-- Name: idx_26540_fk_software_licence_idx; Type: INDEX; Schema: public; Owner: comptoir
--

CREATE INDEX idx_26540_fk_software_licence_idx
    ON softwares USING BTREE (licence_id);

--
-- Name: idx_26540_software_url_repository_unique; Type: INDEX; Schema: public; Owner: comptoir
--

CREATE UNIQUE INDEX idx_26540_software_url_repository_unique
    ON softwares USING BTREE (url_repository);

--
-- Name: idx_26540_softwarename_unique; Type: INDEX; Schema: public; Owner: comptoir
--

CREATE UNIQUE INDEX idx_26540_softwarename_unique
    ON softwares USING BTREE (softwarename);

--
-- Name: idx_26549_fk_users_user_types_idx; Type: INDEX; Schema: public; Owner: comptoir
--

CREATE INDEX idx_26549_fk_users_user_types_idx
    ON users USING BTREE (user_type_id);

--
-- Name: fk_entities_relationships_relationtion_types; Type: FK CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY relationships_users
    ADD CONSTRAINT fk_entities_relationships_relationtion_types FOREIGN KEY (relationship_id) REFERENCES relationships (id);

--
-- Name: fk_entities_relationships_users; Type: FK CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY relationships_users
    ADD CONSTRAINT fk_entities_relationships_users FOREIGN KEY (user_id) REFERENCES users (id);

--
-- Name: fk_entities_relationships_users_recipient; Type: FK CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY relationships_users
    ADD CONSTRAINT fk_entities_relationships_users_recipient FOREIGN KEY (recipient_id) REFERENCES users (id);

--
-- Name: fk_entity_software_relationship_entity; Type: FK CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY relationships_softwares_users
    ADD CONSTRAINT fk_entity_software_relationship_entity FOREIGN KEY (user_id) REFERENCES users (id);

--
-- Name: fk_license_licence_type; Type: FK CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY licenses
    ADD CONSTRAINT fk_license_licence_type FOREIGN KEY (license_type_id) REFERENCES licence_types (id);

--
-- Name: fk_relationships_relationship_types; Type: FK CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY relationships
    ADD CONSTRAINT fk_relationships_relationship_types FOREIGN KEY (relationship_type_id) REFERENCES relationship_types (id);

--
-- Name: fk_review_software; Type: FK CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY reviews
    ADD CONSTRAINT fk_review_software FOREIGN KEY (software_id) REFERENCES softwares (id);

--
-- Name: fk_review_user; Type: FK CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY reviews
    ADD CONSTRAINT fk_review_user FOREIGN KEY (user_id) REFERENCES users (id);

--
-- Name: fk_screens_software; Type: FK CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY screenshots
    ADD CONSTRAINT fk_screens_software FOREIGN KEY (software_id) REFERENCES softwares (id);

--
-- Name: fk_software_licence; Type: FK CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY softwares
    ADD CONSTRAINT fk_software_licence FOREIGN KEY (licence_id) REFERENCES licenses (id);

--
-- Name: fk_software_relationship_relation_type; Type: FK CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY relationships_softwares
    ADD CONSTRAINT fk_software_relationship_relation_type FOREIGN KEY (relationship_id) REFERENCES relationships (id);

--
-- Name: fk_software_relationship_software_from; Type: FK CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY relationships_softwares
    ADD CONSTRAINT fk_software_relationship_software_from FOREIGN KEY (software_id) REFERENCES softwares (id);

--
-- Name: fk_software_relationship_to; Type: FK CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY relationships_softwares
    ADD CONSTRAINT fk_software_relationship_to FOREIGN KEY (recipient_id) REFERENCES softwares (id);

--
-- Name: fk_softwares; Type: FK CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY softwares_statistics
    ADD CONSTRAINT fk_softwares FOREIGN KEY (software_id) REFERENCES softwares (id);

--
-- Name: fk_user_software_relationship_relationship_type; Type: FK CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY relationships_softwares_users
    ADD CONSTRAINT fk_user_software_relationship_relationship_type FOREIGN KEY (relationship_id) REFERENCES relationships (id);

--
-- Name: fk_user_software_relationship_software; Type: FK CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY relationships_softwares_users
    ADD CONSTRAINT fk_user_software_relationship_software FOREIGN KEY (software_id) REFERENCES softwares (id);

--
-- Name: fk_user_user_type; Type: FK CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY users
    ADD CONSTRAINT fk_user_user_type FOREIGN KEY (user_type_id) REFERENCES user_types (id);

--
-- Name: raw_metrics_softwares_software_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: comptoir
--

ALTER TABLE ONLY raw_metrics_softwares
    ADD CONSTRAINT raw_metrics_softwares_software_id_fkey FOREIGN KEY (software_id) REFERENCES softwares (id);



--
-- PostgreSQL database dump complete
--

